import json

import click

from stumpfwald import authorized, cli


@click.group(name='app', short_help='The annotation app resource')
@click.pass_obj
def app(ctx):
    pass


@app.command(name='list', help='List  annotation apps')
@click.pass_obj
@authorized
def list_(ctx):
    r = ctx['session'].get('annotation-app')

    if not r.ok:
        click.echo(r.text, err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


@app.command(name='describe', help='Retrieve a single annotation app')
@click.argument('app_id')
@click.pass_obj
@authorized
def describe_(ctx, app_id):
    r = ctx['session'].get(f'annotation-app/{app_id}')

    if not r.ok:
        click.echo(r.text, err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


@app.command(name='delete', help='Delete an annotation app')
@click.argument('app_id')
@click.pass_obj
@authorized
def delete_(ctx, app_id):
    r = ctx['session'].delete(f'annotation-app/{app_id}')

    if not r.ok:
        click.echo(r.text, err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


@app.command(name='create', help='Create an annotation app')
@click.argument('name')
@click.argument('repo_url')
@click.argument('url')
@click.pass_obj
@authorized
def create_(ctx, name, repo_url, url):
    r = ctx['session'].post('annotation-app', json={
      'name': name,
      'repo_url': repo_url,
      'url': url
    })

    if not r.ok:
        click.echo(r.text, err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


cli.add_command(app)
