import json

import click

from stumpfwald import authorized, cli


@click.group(name='answer', short_help='The answer resource.')
@click.pass_obj
def answer(ctx):
    pass


@answer.command(name='create', help='Create an answer for an assignment')
@click.argument('assignment-id')
@click.argument('path')
@click.pass_obj
@authorized
def create(ctx, assignment_id, path):
    r = ctx['session'].post('answer', json={
        'assignment_id': assignment_id,
        'path': path
    })

    if not r.ok:
        click.echo(r.text, err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


@answer.command(name='list', help='List answers for an assignment')
@click.argument('assignment-id')
@click.pass_obj
@authorized
def list_(ctx, assignment_id):
    r = ctx['session'].get(f'answer/{assignment_id}')

    if not r.ok:
        click.echo(r.text, err=True)
    else:
        click.echo(json.dumps(r.json(), indent=4))


cli.add_command(answer)
